package cn.wisenergy.service.impl;

import cn.wisenergy.common.utils.exception.BASE_RESP_CODE_ENUM;
import cn.wisenergy.common.utils.exception.BaseCustomException;
import cn.wisenergy.mapper.WorkProjectMapper;
import cn.wisenergy.model.app.WorkProject;
import cn.wisenergy.model.app.WorkUser;
import cn.wisenergy.model.enums.ManagerEnum;
import cn.wisenergy.service.WorkProjectService;
import cn.wisenergy.service.WorkUserService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author chenqi
 * @since 2021-01-19
 */
@Service
@Slf4j
public class WorkProjectServiceImpl implements WorkProjectService {

    @Autowired
    private WorkUserService workUserService;

    @Autowired
    private WorkProjectMapper workProjectMapper;

    @Override
    public List<WorkProject> getUserManageProjects(Integer userId) {
        log.info("WorkProjectServiceImpl[]getUserManageProjects[]input.param" + userId);
        if (userId == null) {
            throw new BaseCustomException(BASE_RESP_CODE_ENUM.INPUT_PARAM_IS_NULL);
        }
        WorkUser user = workUserService.getUserById(userId);
        List<WorkProject> workProjects = new ArrayList<>();
        HashMap<String, Object> map = new HashMap<>();
        if (user.getLevel() == ManagerEnum.IS_PROJECT_DIRECTOR.getCode()) {
            map.put("managerId", userId);
            workProjects = workProjectMapper.getProjectsByCriteria(map);
        }
        //用户是部门级别，查询该部门下的所有项目
        if (user.getLevel() == ManagerEnum.IS_DEPARTMENT_DIRECTOR.getCode()) {
            map.put("deptId", user.getDeptId());
            workProjects = workProjectMapper.getProjectsByCriteria(map);
        }
        return workProjects;
    }
}
